Brief Introduction

Python-Extension is an extension of Python,
It is divided into pyextension and tkextension,
tkextension is particularly powerful. 


Pyextensionass

Pyextension includes main modules
(open source function, computer information function),
mathematical function processing module, password encryption module,
English Thesaurus module and Microsoft Word document processing module.


Tkextension

Tkextense includes dialog window,tix widget,
quick generation of Tkinter object,
quick document processing (open and save as),
open source module,
tix module, ttk module,
small blackboard module, turtle graphics drawing module and timer module